==> fastapi_forge-0.5.1-py3-none-any.whl: fastapi_forge/frontend/constants.py <==
from typing import Any

from fastapi_forge.dtos import ModelField
from fastapi_forge.enums import FieldDataType

SELECTED_MODEL_TEXT_COLOR = "text-black-500 dark:text-amber-300"

FIELD_COLUMNS: list[dict[str, Any]] = [
    {
        "name": "name",
        "label": "Name",
        "field": "name",
        "required": True,
        "align": "left",
    },
    {"name": "type", "label": "Type", "field": "type", "align": "left"},
    {
        "name": "primary_key",
        "label": "Primary Key",
        "field": "primary_key",
        "align": "center",
    },
    {"name": "nullable", "label": "Nullable", "field": "nullable", "align": "center"},
    {"name": "unique", "label": "Unique", "field": "unique", "align": "center"},
    {"name": "index", "label": "Index", "field": "index", "align": "center"},
]

RELATIONSHIP_COLUMNS: list[dict[str, Any]] = [
    {
        "name": "field_name",
        "label": "Field Name",
        "field": "field_name",
        "required": True,
        "align": "left",
    },
    {
        "name": "target_model",
        "label": "Target Model",
        "field": "target_model",
        "align": "left",
    },
    {
        "name": "back_populates",
        "label": "Back Populates",
        "field": "back_populates",
        "align": "left",
    },
    {"name": "nullable", "label": "Nullable", "field": "nullable", "align": "center"},
    {"name": "index", "label": "Index", "field": "index", "align": "center"},
    {"name": "unique", "label": "Unique", "field": "unique", "align": "center"},
]


DEFAULT_AUTH_USER_FIELDS: list[ModelField] = [
    ModelField(
        name="email",
        type=FieldDataType.STRING,
        unique=True,
        index=True,
    ),
    ModelField(
        name="password",
        type=FieldDataType.STRING,
    ),
]

==> fastapi_forge-0.6.0-py3-none-any.whl: fastapi_forge/frontend/constants.py <==
from typing import Any

from fastapi_forge.dtos import ModelField
from fastapi_forge.enums import FieldDataTypeEnum

SELECTED_MODEL_TEXT_COLOR = "text-black-500 dark:text-amber-300"
SELECTED_ENUM_TEXT_COLOR = "text-black-500 dark:text-amber-300"

FIELD_COLUMNS: list[dict[str, Any]] = [
    {
        "name": "name",
        "label": "Name",
        "field": "name",
        "required": True,
        "align": "left",
    },
    {"name": "type", "label": "Type", "field": "type", "align": "left"},
    {
        "name": "primary_key",
        "label": "Primary Key",
        "field": "primary_key",
        "align": "center",
    },
    {"name": "nullable", "label": "Nullable", "field": "nullable", "align": "center"},
    {"name": "unique", "label": "Unique", "field": "unique", "align": "center"},
    {"name": "index", "label": "Index", "field": "index", "align": "center"},
]

ENUM_COLUMNS: list[dict[str, Any]] = [
    {
        "name": "name",
        "label": "Name",
        "field": "name",
        "required": True,
        "align": "left",
    },
    {
        "name": "value",
        "label": "Value",
        "field": "value",
        "required": True,
        "align": "left",
    },
]

RELATIONSHIP_COLUMNS: list[dict[str, Any]] = [
    {
        "name": "field_name",
        "label": "Field Name",
        "field": "field_name",
        "required": True,
        "align": "left",
    },
    {
        "name": "target_model",
        "label": "Target Model",
        "field": "target_model",
        "align": "left",
    },
    {
        "name": "on_delete",
        "label": "On Delete",
        "field": "on_delete",
        "align": "left",
    },
    {"name": "nullable", "label": "Nullable", "field": "nullable", "align": "center"},
    {"name": "index", "label": "Index", "field": "index", "align": "center"},
    {"name": "unique", "label": "Unique", "field": "unique", "align": "center"},
]


DEFAULT_AUTH_USER_FIELDS: list[ModelField] = [
    ModelField(
        name="email",
        type=FieldDataTypeEnum.STRING,
        unique=True,
        index=True,
    ),
    ModelField(
        name="password",
        type=FieldDataTypeEnum.STRING,
    ),
]
